@@ -1,5 +1,5 @@
 #**
-# * Copyright (c) 2020 Weitian Leung
+# * Copyright (c) 2020-2021 Weitian Leung
 # *
 # * This file is part of pywpsrpc.
 # *
@@ -22,6 +22,7 @@ var_pattern = re.compile(
 class PyWpsRpcProject(sipbuild.Project):
     def __init__(self):
         super().__init__(dunder_init=True)
+        self.abi_version = "12"
 
         self.bindings_factories = [RpcCommon, RpcWpsApi, RpcWppApi, RpcEtApi]
         self.sdk_inc_dir = os.path.join(self.root_dir, "include")
@@ -145,41 +146,6 @@ class RpcCommon(RpcApiBindings):
     def generate(self):
         buildable = super().generate()
         self._fix_sip(buildable)
-
-        # hack the code to fix the BSTR memory leak!!!
-        # FIXME: the right way is write the %MethodCode for
-        # each method that contains the BSTR argument...
-        bstr_cpp = os.path.join(
-            buildable.build_dir,
-            "sip" + buildable.target + "BSTR.cpp")
-
-        tmp_file = bstr_cpp + ".tmp"
-
-        f_in = open(bstr_cpp, "rb")
-        f_out = open(tmp_file, "wb+")
-
-        release_pattern = b"static void release_BSTR(void *ptr, int)\n"
-
-        state = 0
-        for line in f_in:
-            if state == 0 and line == release_pattern:
-                state = 1
-            elif state == 1 and line == b'{\n':
-                f_out.write(line)
-                f_out.write(
-                    b"    BSTR *pBstr = reinterpret_cast<BSTR*>(ptr);\n")
-                f_out.write(b"    if (*pBstr)\n")
-                f_out.write(b"        _SysFreeString(*pBstr);\n")
-                state = 2
-                continue
-
-            f_out.write(line)
-
-        f_in.close()
-        f_out.close()
-
-        shutil.move(tmp_file, bstr_cpp)
-
         return buildable
 
     def _fix_sip(self, buildable):
